DeliveryTimeSlot enum

Delivery Time Slots - synchronized with TypeScript shared model

Inheritance
Available extensions

Values

morning → const DeliveryTimeSlot
const DeliveryTimeSlot('morning')
lunch → const DeliveryTimeSlot
const DeliveryTimeSlot('lunch')
afternoon → const DeliveryTimeSlot
const DeliveryTimeSlot('afternoon')
evening → const DeliveryTimeSlot
const DeliveryTimeSlot('evening')
night → const DeliveryTimeSlot
const DeliveryTimeSlot('night')

Properties

displayName String

Available on Enum, provided by the EnumExtensions extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringValue String

Available on Enum, provided by the EnumExtensions extension

no setter
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DeliveryTimeSlot>
A constant List of the values in this enum, in order of their declaration.