DynamicCategory class abstract

  1. DYNAMIC CATEGORY (managed from admin panel)

Constructors

DynamicCategory()

Properties

allowMultiple bool?
no setter
applicableMealTypes List<String>?
no setter
color String?
no setter
createdAt DateTime?
no setter
createdBy String?
no setter
description String?
no setter
displayOrder int?
no setter
hashCode int
The hash code for this object.
no setterinherited
icon String?
no setter
id String?
no setter
isActive bool?
no setter
isRequired bool?
no setter
kitchenId String?
no setter
maxSelections int?
no setter
minSelections int?
no setter
name String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
no setter
updatedAt DateTime?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited