ReviewReport class abstract

ReviewReport interface

Inheritance

Constructors

ReviewReport()

Properties

createdAt DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
no setterinherited
moderatorNotes String?
no setter
reason String?
no setter
reporterId String?
no setter
reviewId String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
no setter
updatedAt DateTime?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited