SupportMessage class abstract
SupportMessage interface
- Inheritance
-
- Object
- BaseEntity
- SupportMessage
Constructors
Properties
-
attachments
→ List<
String> ? -
no setter
- content → String?
-
no setter
- createdAt → DateTime?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
no setterinherited
- messageType → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderId → String?
-
no setter
- senderType → String?
-
no setter
- ticketId → String?
-
no setter
- updatedAt → DateTime?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited