MenuCategory class abstract
MenuCategory interface
- Inheritance
-
- Object
- BaseEntity
- MenuCategory
Constructors
Properties
- createdAt → DateTime?
-
no setterinherited
- description → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
no setterinherited
- image → String?
-
no setter
- isActive → bool?
-
no setter
- kitchenId → String?
-
no setter
- level → int?
-
no setter
- name → String?
-
no setter
- parentCategoryId → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortOrder → int?
-
no setter
- updatedAt → DateTime?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited