Offer class abstract
Offer interface
- Inheritance
-
- Object
- BaseEntity
- Offer
Constructors
- Offer()
Properties
- createdAt → DateTime?
-
no setterinherited
- description → String?
-
no setter
- discountType → String?
-
no setter
- discountValue → double?
-
no setter
- endDate → DateTime?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
no setterinherited
- isActive → bool?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → DateTime?
-
no setter
- title → String?
-
no setter
- type → String?
-
no setter
- updatedAt → DateTime?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited